@@ -10,11 +10,11 @@
     :license: BSD, see LICENSE for details.
 """
 
-# "raises" imported for usage by autodoc
-from util import TestApp, Struct, raises, SkipTest  # NOQA
-from nose.tools import with_setup, eq_
+from util import SphinxTestApp, Struct  # NOQA
+import pytest
 
-from six import StringIO
+import enum
+from six import StringIO, add_metaclass
 from docutils.statemachine import ViewList
 
 from sphinx.ext.autodoc import AutoDirective, add_documenter, \
@@ -25,7 +25,7 @@ app = None
 
 def setup_module():
     global app
-    app = TestApp()
+    app = SphinxTestApp()
     app.builder.env.app = app
     app.builder.env.temp_data['docname'] = 'dummy'
     app.connect('autodoc-process-docstring', process_docstring)
@@ -40,6 +40,7 @@ def teardown_module():
 directive = options = None
 
 
+@pytest.fixture
 def setup_test():
     global options, directive
     global processed_docstrings, processed_signatures, _warnings
@@ -73,6 +74,10 @@ def setup_test():
     processed_signatures = []
     _warnings = []
 
+    yield
+
+    AutoDirective._special_attrgetters.clear()
+
 
 _warnings = []
 processed_docstrings = []
@@ -104,7 +109,7 @@ def skip_member(app, what, name, obj, skip, options):
         return True
 
 
-@with_setup(setup_test)
+@pytest.mark.usefixtures('setup_test')
 def test_parse_name():
     def verify(objtype, name, result):
         inst = AutoDirective._registry[objtype](directive, name)
@@ -119,26 +124,27 @@ def test_parse_name():
     del _warnings[:]
 
     # for functions/classes
-    verify('function', 'util.raises', ('util', ['raises'], None, None))
-    verify('function', 'util.raises(exc) -> None',
-           ('util', ['raises'], 'exc', 'None'))
-    directive.env.temp_data['autodoc:module'] = 'util'
-    verify('function', 'raises', ('util', ['raises'], None, None))
+    verify('function', 'test_autodoc.raises',
+           ('test_autodoc', ['raises'], None, None))
+    verify('function', 'test_autodoc.raises(exc) -> None',
+           ('test_autodoc', ['raises'], 'exc', 'None'))
+    directive.env.temp_data['autodoc:module'] = 'test_autodoc'
+    verify('function', 'raises', ('test_autodoc', ['raises'], None, None))
     del directive.env.temp_data['autodoc:module']
-    directive.env.ref_context['py:module'] = 'util'
-    verify('function', 'raises', ('util', ['raises'], None, None))
-    verify('class', 'TestApp', ('util', ['TestApp'], None, None))
+    directive.env.ref_context['py:module'] = 'test_autodoc'
+    verify('function', 'raises', ('test_autodoc', ['raises'], None, None))
+    verify('class', 'Base', ('test_autodoc', ['Base'], None, None))
 
     # for members
     directive.env.ref_context['py:module'] = 'foo'
-    verify('method', 'util.TestApp.cleanup',
-           ('util', ['TestApp', 'cleanup'], None, None))
+    verify('method', 'util.SphinxTestApp.cleanup',
+           ('util', ['SphinxTestApp', 'cleanup'], None, None))
     directive.env.ref_context['py:module'] = 'util'
     directive.env.ref_context['py:class'] = 'Foo'
-    directive.env.temp_data['autodoc:class'] = 'TestApp'
-    verify('method', 'cleanup', ('util', ['TestApp', 'cleanup'], None, None))
-    verify('method', 'TestApp.cleanup',
-           ('util', ['TestApp', 'cleanup'], None, None))
+    directive.env.temp_data['autodoc:class'] = 'SphinxTestApp'
+    verify('method', 'cleanup', ('util', ['SphinxTestApp', 'cleanup'], None, None))
+    verify('method', 'SphinxTestApp.cleanup',
+           ('util', ['SphinxTestApp', 'cleanup'], None, None))
 
     # and clean up
     del directive.env.ref_context['py:module']
@@ -146,7 +152,7 @@ def test_parse_name():
     del directive.env.temp_data['autodoc:class']
 
 
-@with_setup(setup_test)
+@pytest.mark.usefixtures('setup_test')
 def test_format_signature():
     def formatsig(objtype, name, obj, args, retann):
         inst = AutoDirective._registry[objtype](directive, name)
@@ -252,7 +258,7 @@ def test_format_signature():
         '(b, c=42, *d, **e)'
 
 
-@with_setup(setup_test)
+@pytest.mark.usefixtures('setup_test')
 def test_get_doc():
     def getdocl(objtype, obj, encoding=None):
         inst = AutoDirective._registry[objtype](directive, 'tmp')
@@ -422,7 +428,7 @@ def test_get_doc():
     assert getdocl('class', I) == ['Class docstring', '', 'New docstring']
 
 
-@with_setup(setup_test)
+@pytest.mark.usefixtures('setup_test')
 def test_docstring_processing():
     def process(objtype, name, obj):
         inst = AutoDirective._registry[objtype](directive, name)
@@ -477,7 +483,7 @@ def test_docstring_processing():
     app.disconnect(lid)
 
 
-@with_setup(setup_test)
+@pytest.mark.usefixtures('setup_test')
 def test_docstring_property_processing():
     def genarate_docstring(objtype, name, **kw):
         del processed_docstrings[:]
@@ -514,7 +520,7 @@ def test_docstring_property_processing():
     assert 'Second line of docstring' in docstrings
 
 
-@with_setup(setup_test)
+@pytest.mark.usefixtures('setup_test')
 def test_new_documenter():
     class MyDocumenter(ModuleLevelDocumenter):
         objtype = 'integer'
@@ -542,7 +548,7 @@ def test_new_documenter():
     assert_result_contains('.. py:data:: integer', 'module', 'test_autodoc')
 
 
-@with_setup(setup_test, AutoDirective._special_attrgetters.clear)
+@pytest.mark.usefixtures('setup_test')
 def test_attrgetter_using():
     def assert_getter_works(objtype, name, obj, attrs=[], **kw):
         getattr_spy = []
@@ -574,7 +580,7 @@ def test_attrgetter_using():
     assert_getter_works('class', 'test_autodoc.Class', Class, ['meth', 'inheritedmeth'])
 
 
-@with_setup(setup_test)
+@pytest.mark.usefixtures('setup_test')
 def test_generate():
     def assert_warns(warn_str, objtype, name, **kw):
         inst = AutoDirective._registry[objtype](directive, name)
@@ -652,7 +658,7 @@ def test_generate():
                            'Class.meth', more_content=add_content)
 
     # test check_module
-    inst = FunctionDocumenter(directive, 'raises')
+    inst = FunctionDocumenter(directive, 'add_documenter')
     inst.generate(check_module=True)
     assert len(directive.result) == 0
 
@@ -825,12 +831,45 @@ def test_generate():
     del directive.env.temp_data['autodoc:module']
     del directive.env.ref_context['py:module']
 
+    # test members with enum attributes
+    directive.env.ref_context['py:module'] = 'test_autodoc'
+    options.inherited_members = False
+    options.undoc_members = False
+    options.members = ALL
+    assert_processes([
+        ('class', 'test_autodoc.EnumCls'),
+        ('attribute', 'test_autodoc.EnumCls.val1'),
+        ('attribute', 'test_autodoc.EnumCls.val2'),
+        ('attribute', 'test_autodoc.EnumCls.val3'),
+    ], 'class', 'EnumCls')
+    assert_result_contains(
+        '   :annotation: = 12', 'attribute', 'EnumCls.val1')
+    assert_result_contains(
+        '   :annotation: = 23', 'attribute', 'EnumCls.val2')
+    assert_result_contains(
+        '   :annotation: = 34', 'attribute', 'EnumCls.val3')
+    del directive.env.temp_data['autodoc:class']
+    del directive.env.temp_data['autodoc:module']
+
     # test descriptor class documentation
-    options.members = ['CustomDataDescriptor']
+    options.members = ['CustomDataDescriptor', 'CustomDataDescriptor2']
     assert_result_contains('.. py:class:: CustomDataDescriptor(doc)',
                            'module', 'test_autodoc')
     assert_result_contains('   .. py:method:: CustomDataDescriptor.meth()',
                            'module', 'test_autodoc')
+    assert_result_contains('.. py:class:: CustomDataDescriptor2(doc)',
+                           'module', 'test_autodoc')
+
+    # test mocked module imports
+    options.members = ['TestAutodoc']
+    options.undoc_members = False
+    assert_result_contains('.. py:class:: TestAutodoc',
+                           'module', 'autodoc_missing_imports')
+    assert_result_contains('   .. py:method:: TestAutodoc.decoratedMethod()',
+                           'module', 'autodoc_missing_imports')
+    options.members = ['decoratedFunction']
+    assert_result_contains('.. py:function:: decoratedFunction()',
+                           'module', 'autodoc_missing_imports')
 
 # --- generate fodder ------------
 __all__ = ['Class']
@@ -839,6 +878,11 @@ __all__ = ['Class']
 integer = 1
 
 
+def raises(exc, func, *args, **kwds):
+    """Raise AssertionError if ``func(*args, **kwds)`` does not raise *exc*."""
+    pass
+
+
 class CustomEx(Exception):
     """My custom exception."""
 
@@ -862,6 +906,14 @@ class CustomDataDescriptor(object):
         return "The Answer"
 
 
+class CustomDataDescriptorMeta(type):
+    """Descriptor metaclass docstring."""
+
+@add_metaclass(CustomDataDescriptorMeta)
+class CustomDataDescriptor2(CustomDataDescriptor):
+    """Descriptor class with custom metaclass docstring."""
+
+
 def _funky_classmethod(name, b, c, d, docstring=None):
     """Generates a classmethod for a class from a template by filling out
     some arguments."""
@@ -1020,17 +1072,29 @@ class InstAttCls(object):
         """Docstring for instance attribute InstAttCls.ia2."""
 
 
+class EnumCls(enum.Enum):
+    """
+    this is enum class
+    """
+
+    #: doc for val1
+    val1 = 12
+    val2 = 23  #: doc for val2
+    val3 = 34
+    """doc for val3"""
+
+
 def test_type_hints():
     from sphinx.ext.autodoc import formatargspec
     from sphinx.util.inspect import getargspec
 
     try:
-        from typing_test_data import f0, f1, f2, f3, f4, f5, f6, f7, f8
+        from typing_test_data import f0, f1, f2, f3, f4, f5, f6, f7, f8, f9, f10, f11
     except (ImportError, SyntaxError):
-        raise SkipTest('Cannot import Python code with function annotations')
+        pytest.skip('Cannot import Python code with function annotations')
 
     def verify_arg_spec(f, expected):
-        eq_(formatargspec(f, *getargspec(f)), expected)
+        assert formatargspec(f, *getargspec(f)) == expected
 
     # Class annotations
     verify_arg_spec(f0, '(x: int, y: numbers.Integral) -> None')
@@ -1052,12 +1116,19 @@ def test_type_hints():
     # Keyword-only arguments
     verify_arg_spec(f5, '(x: int, *, y: str, z: str) -> None')
 
+    # Keyword-only arguments with varargs
+    verify_arg_spec(f6, '(x: int, *args, y: str, z: str) -> None')
+
     # Space around '=' for defaults
-    verify_arg_spec(f6, '(x: int = None, y: dict = {}) -> None')
+    verify_arg_spec(f7, '(x: int = None, y: dict = {}) -> None')
 
     # Callable types
-    verify_arg_spec(f7, '(x: typing.Callable[[int, str], int]) -> None')
+    verify_arg_spec(f8, '(x: typing.Callable[[int, str], int]) -> None')
+    verify_arg_spec(f9, '(x: typing.Callable) -> None')
 
     # Tuple types
-    verify_arg_spec(f8, '(x: typing.Tuple[int, str],'
-                        ' y: typing.Tuple[int, ...]) -> None')
+    verify_arg_spec(f10, '(x: typing.Tuple[int, str],'
+                         ' y: typing.Tuple[int, ...]) -> None')
+
+    # Instance annotations
+    verify_arg_spec(f11, '(x: CustomAnnotation, y: 123) -> None')
