@@ -9,50 +9,34 @@
     :license: BSD, see LICENSE for details.
 """
 
-from six import BytesIO
-
 import pickle
 from docutils import nodes
+import mock
+import pytest
 from textwrap import dedent
 from sphinx.errors import SphinxError
-import sphinx.builders.linkcheck
 
-from util import with_app, rootdir, tempdir, SkipTest, TestApp
-
-try:
-    from docutils.writers.manpage import Writer as ManWriter
-except ImportError:
-    ManWriter = None
+from util import rootdir, tempdir, path
 
 
-class MockOpener(object):
-    def open(self, req, **kwargs):
-        class result(BytesIO):
-            headers = None
-            url = req.url
-        return result()
-
-sphinx.builders.linkcheck.opener = MockOpener()
+def request_session_head(url, **kwargs):
+    response = mock.Mock()
+    response.status_code = 200
+    response.url = url
+    return response
 
 
-def verify_build(buildername, srcdir):
-    if buildername == 'man' and ManWriter is None:
-        raise SkipTest('man writer is not available')
-    app = TestApp(buildername=buildername, srcdir=srcdir)
-    try:
-        app.builder.build_all()
-    finally:
-        app.cleanup()
-
-
-def test_build_all():
+@pytest.fixture
+def nonascii_srcdir(request):
     # If supported, build in a non-ASCII source dir
     test_name = u'\u65e5\u672c\u8a9e'
+    basedir = tempdir / request.node.originalname
     try:
-        srcdir = tempdir / test_name
-        (rootdir / 'root').copytree(tempdir / test_name)
+        srcdir = basedir / test_name
+        if not srcdir.exists():
+            (rootdir / 'root').copytree(srcdir)
     except UnicodeEncodeError:
-        srcdir = tempdir / 'all'
+        srcdir = basedir / 'all'
     else:
         # add a doc with a non-ASCII file name to the source dir
         (srcdir / (test_name + '.txt')).write_text(dedent("""
@@ -66,29 +50,36 @@ def test_build_all():
 
                    %(test_name)s/%(test_name)s
                 """ % {'test_name': test_name})
-        )
-
-    # note: no 'html' - if it's ok with dirhtml it's ok with html
-    for buildername in ['dirhtml', 'singlehtml', 'latex', 'texinfo', 'pickle',
-                        'json', 'text', 'htmlhelp', 'qthelp', 'epub', 'epub3',
-                        'applehelp', 'changes', 'xml', 'pseudoxml', 'man',
-                        'linkcheck']:
-        yield verify_build, buildername, srcdir
+                              )
+    return srcdir
 
 
-@with_app(buildername='text')
-def test_master_doc_not_found(app, status, warning):
-    (app.srcdir / 'contents.txt').move(app.srcdir / 'contents.txt.bak')
-    try:
+@pytest.mark.parametrize(
+    "buildername",
+    [
+        # note: no 'html' - if it's ok with dirhtml it's ok with html
+        'dirhtml', 'singlehtml', 'latex', 'texinfo', 'pickle', 'json', 'text',
+        'htmlhelp', 'qthelp', 'epub2', 'epub', 'applehelp', 'changes', 'xml',
+        'pseudoxml', 'man', 'linkcheck',
+    ],
+)
+@mock.patch('sphinx.builders.linkcheck.requests.head',
+            side_effect=request_session_head)
+def test_build_all(requests_head, make_app, nonascii_srcdir, buildername):
+    app = make_app(buildername, srcdir=nonascii_srcdir)
+    app.build()
+
+
+def test_master_doc_not_found(tempdir, make_app):
+    (tempdir / 'conf.py').write_text('master_doc = "index"')
+    assert tempdir.listdir() == ['conf.py']
+
+    app = make_app('dummy', srcdir=tempdir)
+    with pytest.raises(SphinxError):
         app.builder.build_all()
-        assert False  # SphinxError not raised
-    except Exception as exc:
-        assert isinstance(exc, SphinxError)
-    finally:
-        (app.srcdir / 'contents.txt.bak').move(app.srcdir / 'contents.txt')
 
 
-@with_app(buildername='text', testroot='circular')
+@pytest.mark.sphinx(buildername='text', testroot='circular')
 def test_circular_toctree(app, status, warning):
     app.builder.build_all()
     warnings = warning.getvalue()
@@ -100,7 +91,7 @@ def test_circular_toctree(app, status, warning):
         'contents <- sub <- contents') in warnings
 
 
-@with_app(buildername='text', testroot='numbered-circular')
+@pytest.mark.sphinx(buildername='text', testroot='numbered-circular')
 def test_numbered_circular_toctree(app, status, warning):
     app.builder.build_all()
     warnings = warning.getvalue()
@@ -112,7 +103,7 @@ def test_numbered_circular_toctree(app, status, warning):
         'contents <- sub <- contents') in warnings
 
 
-@with_app(buildername='dummy', testroot='image-glob')
+@pytest.mark.sphinx(buildername='dummy', testroot='image-glob')
 def test_image_glob(app, status, warning):
     app.builder.build_all()
 
@@ -145,16 +136,17 @@ def test_image_glob(app, status, warning):
     doctree = pickle.loads((app.doctreedir / 'subdir/index.doctree').bytes())
 
     assert isinstance(doctree[0][1], nodes.image)
-    assert doctree[0][1]['candidates'] == {'*': 'subdir/rimg.png'}
-    assert doctree[0][1]['uri'] == 'subdir/rimg.png'
+    sub = path('subdir')
+    assert doctree[0][1]['candidates'] == {'*': sub / 'rimg.png'}
+    assert doctree[0][1]['uri'] == sub / 'rimg.png'
 
     assert isinstance(doctree[0][2], nodes.image)
     assert doctree[0][2]['candidates'] == {'application/pdf': 'subdir/svgimg.pdf',
                                            'image/svg+xml': 'subdir/svgimg.svg'}
-    assert doctree[0][2]['uri'] == 'subdir/svgimg.*'
+    assert doctree[0][2]['uri'] == sub / 'svgimg.*'
 
     assert isinstance(doctree[0][3], nodes.figure)
     assert isinstance(doctree[0][3][0], nodes.image)
     assert doctree[0][3][0]['candidates'] == {'application/pdf': 'subdir/svgimg.pdf',
                                               'image/svg+xml': 'subdir/svgimg.svg'}
-    assert doctree[0][3][0]['uri'] == 'subdir/svgimg.*'
+    assert doctree[0][3][0]['uri'] == sub / 'svgimg.*'
