@@ -5,18 +5,18 @@
 
     Test the only directive with the test root.
 
-    :copyright: Copyright 2007-2015 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2016 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
 import re
 
 from docutils import nodes
-
-from util import with_app
+from sphinx.util.nodes import process_only_nodes
+import pytest
 
 
-@with_app('text', testroot='directive-only')
+@pytest.mark.sphinx('text', testroot='directive-only')
 def test_sectioning(app, status, warning):
 
     def getsects(section):
@@ -46,7 +46,7 @@ def test_sectioning(app, status, warning):
 
     app.builder.build(['only'])
     doctree = app.env.get_doctree('only')
-    app.env.process_only_nodes(doctree, app.builder)
+    process_only_nodes(doctree, app.builder.tags)
 
     parts = [getsects(n)
              for n in [_n for _n in doctree.children if isinstance(_n, nodes.section)]]
