@@ -11,10 +11,31 @@
 
 import re
 
-from util import with_app, SkipTest
+import pytest
+from util import SkipTest
 
 
-@with_app('html', testroot='ext-math',
+@pytest.mark.sphinx(
+    'html', testroot='ext-math',
+    confoverrides = {'extensions': ['sphinx.ext.jsmath'], 'jsmath_path': 'dummy.js'})
+def test_jsmath(app, status, warning):
+    app.builder.build_all()
+    content = (app.outdir / 'math.html').text()
+
+    assert '<div class="math">\na^2 + b^2 = c^2</div>' in content
+    assert '<div class="math">\n\\begin{split}a + 1 &lt; b\\end{split}</div>' in content
+    assert (u'<span class="eqno">(1)<a class="headerlink" href="#equation-foo" '
+            u'title="Permalink to this equation">\xb6</a></span>'
+            u'<div class="math" id="equation-foo">\ne^{i\\pi} = 1</div>' in content)
+    assert (u'<span class="eqno">(2)<a class="headerlink" href="#equation-math:0" '
+            u'title="Permalink to this equation">\xb6</a></span>'
+            u'<div class="math" id="equation-math:0">\n'
+            u'e^{ix} = \\cos x + i\\sin x</div>' in content)
+    assert '<div class="math">\nn \\in \\mathbb N</div>' in content
+    assert '<div class="math">\na + 1 &lt; b</div>' in content
+
+
+@pytest.mark.sphinx('html', testroot='ext-math-simple',
           confoverrides = {'extensions': ['sphinx.ext.imgmath']})
 def test_imgmath_png(app, status, warning):
     app.builder.build_all()
@@ -29,7 +50,7 @@ def test_imgmath_png(app, status, warning):
     assert re.search(html, content, re.S)
 
 
-@with_app('html', testroot='ext-math',
+@pytest.mark.sphinx('html', testroot='ext-math-simple',
           confoverrides={'extensions': ['sphinx.ext.imgmath'],
                          'imgmath_image_format': 'svg'})
 def test_imgmath_svg(app, status, warning):
@@ -45,7 +66,7 @@ def test_imgmath_svg(app, status, warning):
     assert re.search(html, content, re.S)
 
 
-@with_app('html', testroot='ext-math',
+@pytest.mark.sphinx('html', testroot='ext-math',
           confoverrides={'extensions': ['sphinx.ext.mathjax']})
 def test_mathjax_align(app, status, warning):
     app.builder.build_all()
@@ -57,19 +78,19 @@ def test_mathjax_align(app, status, warning):
     assert re.search(html, content, re.S)
 
 
-@with_app('html', testroot='ext-math',
+@pytest.mark.sphinx('html', testroot='ext-math',
           confoverrides={'math_number_all': True,
                          'extensions': ['sphinx.ext.mathjax']})
 def test_math_number_all_mathjax(app, status, warning):
     app.builder.build_all()
 
     content = (app.outdir / 'index.html').text()
-    html = (r'<div class="math">\s*'
-            r'<span class="eqno">\(1\)</span>\\\[a\^2\+b\^2=c\^2\\\]</div>')
+    html = (r'<div class="math" id="equation-index:0">\s*'
+            r'<span class="eqno">\(1\)<a .*>\xb6</a></span>\\\[a\^2\+b\^2=c\^2\\\]</div>')
     assert re.search(html, content, re.S)
 
 
-@with_app('latex', testroot='ext-math',
+@pytest.mark.sphinx('latex', testroot='ext-math',
           confoverrides={'extensions': ['sphinx.ext.mathjax']})
 def test_math_number_all_latex(app, status, warning):
     app.builder.build_all()
@@ -93,3 +114,6 @@ def test_math_number_all_latex(app, status, warning):
              r'V &= \\frac\{4}\{3} \\pi r\^3\\\\\s*'
              r'\\end{aligned}\\end{align\*}')
     assert re.search(macro, content, re.S)
+
+    macro = r'Referencing equation \\eqref{equation:math:foo}.'
+    assert re.search(macro, content, re.S)
