@@ -5,20 +5,24 @@
 
     Test the Theme class.
 
-    :copyright: Copyright 2007-2015 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2016 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
 import os
 import zipfile
 
+import mock
+import pytest
+
 from sphinx.theming import Theme, ThemeError
 
-from util import with_app, raises, TestApp
+from util import with_app, path
 
 
-@with_app(confoverrides={'html_theme': 'ziptheme',
-                         'html_theme_options.testopt': 'foo'})
+@pytest.mark.sphinx(
+    confoverrides={'html_theme': 'ziptheme',
+                   'html_theme_options.testopt': 'foo'})
 def test_theme_api(app, status, warning):
     cfg = app.config
 
@@ -26,7 +30,7 @@ def test_theme_api(app, status, warning):
     assert set(Theme.themes.keys()) == \
         set(['basic', 'default', 'scrolls', 'agogo', 'sphinxdoc', 'haiku',
              'traditional', 'testtheme', 'ziptheme', 'epub', 'nature',
-             'pyramid', 'bizstyle', 'classic'])
+             'pyramid', 'bizstyle', 'classic', 'nonav'])
     assert Theme.themes['testtheme'][1] is None
     assert isinstance(Theme.themes['ziptheme'][1], zipfile.ZipFile)
 
@@ -44,10 +48,12 @@ def test_theme_api(app, status, warning):
     assert theme.get_confstr('options', 'nosidebar') == 'false'
     # nonexisting setting
     assert theme.get_confstr('theme', 'foobar', 'def') == 'def'
-    raises(ThemeError, theme.get_confstr, 'theme', 'foobar')
+    with pytest.raises(ThemeError):
+        theme.get_confstr('theme', 'foobar')
 
     # options API
-    raises(ThemeError, theme.get_options, {'nonexisting': 'foo'})
+    with pytest.raises(ThemeError):
+        theme.get_options({'nonexisting': 'foo'})
     options = theme.get_options(cfg.html_theme_options)
     assert options['testopt'] == 'foo'
     assert options['nosidebar'] == 'false'
@@ -57,7 +63,7 @@ def test_theme_api(app, status, warning):
     assert not os.path.exists(themedir)
 
 
-@with_app(testroot='tocdepth')  # a minimal root
+@pytest.mark.sphinx(testroot='tocdepth')  # a minimal root
 def test_js_source(app, status, warning):
     # Now sphinx provides non-minified JS files for jquery.js and underscore.js
     # to clarify the source of the minified files. see also #1434.
@@ -66,7 +72,7 @@ def test_js_source(app, status, warning):
 
     app.builder.build(['contents'])
 
-    v = '1.11.1'
+    v = '3.1.0'
     msg = 'jquery.js version does not match to {v}'.format(v=v)
     jquery_min = (app.outdir / '_static' / 'jquery.js').text()
     assert 'jQuery v{v}'.format(v=v) in jquery_min, msg
@@ -79,3 +85,18 @@ def test_js_source(app, status, warning):
     assert 'Underscore.js {v}'.format(v=v) in underscore_min, msg
     underscore_src = (app.outdir / '_static' / 'underscore-{v}.js'.format(v=v)).text()
     assert 'Underscore.js {v}'.format(v=v) in underscore_src, msg
+
+
+@pytest.mark.sphinx(testroot='double-inheriting-theme')
+def test_double_inheriting_theme(make_app, app_params):
+    from sphinx.theming import load_theme_plugins  # load original before patching
+
+    def load_themes():
+        roots = path(__file__).abspath().parent / 'roots'
+        yield roots / 'test-double-inheriting-theme' / 'base_themes_dir'
+        for t in load_theme_plugins():
+            yield t
+
+    with mock.patch('sphinx.theming.load_theme_plugins', side_effect=load_themes):
+        args, kwargs = app_params
+        make_app(*args, **kwargs)
